jobtitle

# XMLRésuméLibrary: User Guide

job | Element Reference | keyword

## Name

jobtitle — A job title

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `jobtitle` element specifies the offical title or name of the position a person held at a job.

### Parents

`jobtitle` may be contained in these elements: `job`

## Examples

For examples, see ``job

job | Element Reference | keyword